[Libreoffice-commits] online.git: Branch 'distro/collabora/collabora-online-4' - loleaflet/css loleaflet/src

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Wed Mar 13 08:59:22 UTC 2019


 loleaflet/css/menubar.css |    1 -
 loleaflet/src/map/Map.js  |    6 +++++-
 2 files changed, 5 insertions(+), 2 deletions(-)

New commits:
commit 6a439c210c7224a71a87c556863f66f8e07e08a8
Author:     Jan Holesovsky <kendy at collabora.com>
AuthorDate: Wed Mar 13 09:55:08 2019 +0100
Commit:     Andras Timar <andras.timar at collabora.com>
CommitDate: Wed Mar 13 09:59:04 2019 +0100

    Last modification: Show the pointer cursor only when revision history enabled.
    
    Change-Id: I64ca1936f22fc94d887c01e7ccaca4a84154aa02
    Reviewed-on: https://gerrit.libreoffice.org/69153
    Reviewed-by: Andras Timar <andras.timar at collabora.com>
    Tested-by: Andras Timar <andras.timar at collabora.com>

diff --git a/loleaflet/css/menubar.css b/loleaflet/css/menubar.css
index 4d750b8f5..f8ec2e3ba 100644
--- a/loleaflet/css/menubar.css
+++ b/loleaflet/css/menubar.css
@@ -317,5 +317,4 @@
     padding: 8px 15px 7px 15px;
     z-index: 500;
     border: 1px solid transparent;
-    cursor: pointer;
 }
diff --git a/loleaflet/src/map/Map.js b/loleaflet/src/map/Map.js
index 9f7f35af3..60244aa57 100644
--- a/loleaflet/src/map/Map.js
+++ b/loleaflet/src/map/Map.js
@@ -16,7 +16,7 @@ function moveObjectVertically(obj, diff) {
 	}
 }
 
 /* global timeago closebutton vex $ _ */
 L.Map = L.Evented.extend({
 
 	options: {
@@ -308,6 +308,10 @@ L.Map = L.Evented.extend({
 			// Replace menu button body with new content
 			lastModButton.firstChild.innerHTML = '';
 			lastModButton.firstChild.appendChild(mainSpan);
+
+			if (revHistoryEnabled) {
+				L.DomUtil.setStyle(lastModButton, 'cursor', 'pointer');
+			}
 		}
 	},
 
@@ -16,7 +16,7 @@ function moveObjectVertically(obj, diff) {
 }
 
-/* global timeago closebutton vex $ _ */
+/* global timeago closebutton vex revHistoryEnabled $ _ */
 L.Map = L.Evented.extend({
 


More information about the Libreoffice-commits mailing list